@@ -15,9 +15,12 @@ sub new
     my %options = @_;
     my $dsn = 'DBI:'.$class->dsn(@options{qw(host port database)});
     my $debug = $options{debug}||0;
+    my $fnsep = $options{fnsep}||'.';
     my $self = {
         subpackages => {},
-        limit  => 0 + ($options{limit}||0),
+        limit => 0 + ($options{limit}||0),
+        fnsep => $fnsep,
+        fnsplit => qr/[$fnsep]/,
         dbh => DBI->connect($dsn, @options{qw(user password)},
             {
                 PrintError => $debug > 0,
