@@ -43,7 +43,7 @@ sub get
 
 =begin testing list
 
-list_ok $_tobj->list(), [];
+cmp_set $_tobj->list(), [];
 
 =end testing
 =cut
