@@ -2,11 +2,8 @@ use strict;
 use v5.10.0;
 
 package FusqlFS::Backend::PgSQL::Table::Test;
-use base 'Exporter';
 use FusqlFS::Backend::PgSQL::Test;
 
-our @EXPORT = qw(list_ok);
-
 our $fusqlh;
 
 sub set_up
@@ -14,6 +11,14 @@ sub set_up
     $fusqlh = FusqlFS::Backend::PgSQL::Test->set_up();
     return unless $fusqlh;
     $fusqlh->{subpackages}->{tables}->create('fusqlfs_table');
+    $fusqlh->{subpackages}->{languages}->create('plperl');
+    $fusqlh->{subpackages}->{functions}->store('fusqlfs_function()',
+        {
+            'content.plperl' => 'return;',
+            struct => { result => 'trigger' },
+            language => \'../../languages/sql'
+        }
+    );
 }
 
 sub tear_down
